@@ -298,10 +298,16 @@ gn_quit_app (GtkWidget * widget, gpointer data)
 	return TRUE;
 }
 
+void
+on_beep_activate (GtkWidget *menu_item, gpointer data)
+{
+	Netinfo *ni_data = (Netinfo *) data;
+	ni_data->has_beep =! ni_data->has_beep;
+}
+
 void
 on_about_activate (GtkWidget *menu_item, gpointer data)
 {
-	GdkPixbuf   *pixbuf = NULL;
 	const gchar *authors[] = { 
 		"Germán Poo Caamaño <gpoo@ubiobio.cl>", 
 		"William Jon McCann <mccann@jhu.edu>",
@@ -309,7 +315,7 @@ on_about_activate (GtkWidget *menu_item, gpointer data)
 		"Rodrigo Moya <rodrigo@gnome-db.org>", NULL
 	};
 	const gchar *documentors[] = { NULL };
-	const gchar *translator_credits = _("translator_credits");
+	const gchar *translator_credits = _("translator-credits");
 	gchar	     copyright[1024];
 	GtkWindow   *parent;
 
@@ -317,19 +323,10 @@ on_about_activate (GtkWidget *menu_item, gpointer data)
 
 	g_sprintf (copyright, "Copyright \xc2\xa9 2003-2004 %s", "Germán Poo Caamaño");
 	
-	{
-		gchar *filename = NULL;
-										
-		filename = g_build_filename (PIXMAPS_DIR, "gnome-nettool.png", NULL);
-		if (filename != NULL) {
-			pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-			g_free (filename);
-		}
-	}
-
 	gtk_show_about_dialog (parent,
-			       "name", "Network Tools",
-			       "logo", pixbuf,
+			       /* Dear translator: This is the name of the application */
+			       "name", _("Network Tools"),
+			       "logo-icon-name", "gnome-nettool",
 			       "authors", authors,
 			       "documenters", documentors,
 			       "version", VERSION,
@@ -337,9 +334,6 @@ on_about_activate (GtkWidget *menu_item, gpointer data)
 			       "comments", _("Graphical user interface for common network utilities"),
 			       "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			       NULL);
-
-	if (pixbuf != NULL)
-		g_object_unref (pixbuf);
 }
 
 static Netinfo *
@@ -446,7 +440,9 @@ on_page_switch (GtkNotebook     * notebook,
 		gtk_statusbar_pop (GTK_STATUSBAR (netinfo->status_bar), 0);
 	}
 
-	title = g_strdup_printf ("Network Tools - %s",
+	/* Dear Translator: This is the Window Title. 'Network Tools' is the
+	 * name of the application */
+	title = g_strdup_printf (_("%s - Network Tools"),
 				 gtk_label_get_text (GTK_LABEL (netinfo->page_label)));
 	gtk_window_set_title (GTK_WINDOW (netinfo->main_window), title);
 	g_free (title);
