@@ -53,6 +53,7 @@ main (int argc, char *argv[])
 {
 	GtkWidget *window;
 	GtkWidget *menu_quit, *menu_about, *menu_copy, *menu_clear_history;
+	GtkWidget *menu_beep;
 	GladeXML *xml;
 	GtkWidget *notebook;
 	const gchar *dialog = DATADIR "gnome-nettool.glade";
@@ -64,7 +65,6 @@ main (int argc, char *argv[])
 	Netinfo *lookup;
 	Netinfo *finger;
 	Netinfo *whois;
-	GtkIconInfo *icon_info;
 	gint current_page = 0;
 	static gchar *info_input = NULL;
 	static gchar *ping_input = NULL;
@@ -74,6 +74,8 @@ main (int argc, char *argv[])
 	static gchar *lookup_input = NULL;
 	static gchar *finger_input = NULL;
 	static gchar *whois_input = NULL;
+	GError *error = NULL;
+
 	GOptionEntry options[] = {
 		{ "info", 'i', 0, G_OPTION_ARG_STRING, &info_input,
  		  N_("Load information for a network device"),
@@ -116,7 +118,10 @@ main (int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
-	gtk_init_with_args (&argc, &argv,NULL,options,NULL,NULL);
+	if (!gtk_init_with_args (&argc, &argv, NULL, options, NULL, &error)) {
+		g_print ("%s\n\n", error->message);
+		return -1;
+	}
 
 	if (!g_file_test (dialog, G_FILE_TEST_EXISTS)) {
 		g_critical (_("The file %s doesn't exist, "
@@ -125,12 +130,8 @@ main (int argc, char *argv[])
 		return -1;
 	}
 
-	icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "gnome-nettool", 48, 0);
-	if (icon_info != NULL) {
-		gtk_window_set_default_icon_from_file (gtk_icon_info_get_filename (icon_info), NULL);
-		gtk_icon_info_free (icon_info);
-	}
-
+	gtk_window_set_default_icon_name ("gnome-nettool");
+	
 	xml = glade_xml_new (dialog, "main_window", NULL);
 	window = glade_xml_get_widget (xml, "main_window");
 
@@ -215,6 +216,12 @@ main (int argc, char *argv[])
 	g_signal_connect (G_OBJECT (menu_quit), "activate",
 			  G_CALLBACK (gn_quit_app),
 			  NULL);
+
+	menu_beep = glade_xml_get_widget (xml, "m_beep");
+
+	g_signal_connect (G_OBJECT (menu_beep), "activate",
+			  G_CALLBACK (on_beep_activate),
+			  (gpointer) pinger); 
 	
 	menu_about = glade_xml_get_widget (xml, "m_about");
 
@@ -301,6 +308,7 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	pinger->output = glade_xml_get_widget (xml, "ping_output");
 	pinger->limited = glade_xml_get_widget (xml, "ping_limited");
 	pinger->button = glade_xml_get_widget (xml, "ping_button");
+	pinger->graph = glade_xml_get_widget (xml, "ping_graph");
 	pinger->sensitive = pinger->host;
 	pinger->label_run = _("Ping");
 	pinger->label_stop = NULL;
@@ -312,7 +320,7 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	pinger->max = glade_xml_get_widget (xml, "ping_maximum");
 	pinger->packets_transmitted = glade_xml_get_widget (xml, "ping_packets_transmitted");
 	pinger->packets_received = glade_xml_get_widget (xml, "ping_packets_received");
-	pinger->packets_loss = glade_xml_get_widget (xml, "ping_packets_loss");
+	pinger->packets_success = glade_xml_get_widget (xml, "ping_packets_success");
 
 	pinger->status_bar = glade_xml_get_widget (xml, "statusbar");
 	pinger->stbar_text = NULL;
@@ -359,6 +367,9 @@ load_ping_widgets_from_xml (GladeXML * xml)
 	g_signal_connect (G_OBJECT (pinger->button), "clicked",
 			  pinger->button_callback,
 			  pinger);
+	g_signal_connect (G_OBJECT (pinger->graph), "expose-event",
+			  G_CALLBACK (on_ping_graph_expose),
+			  pinger);
 
 	return pinger;
 }
@@ -916,7 +927,7 @@ load_finger_widgets_from_xml (GladeXML * xml)
 	tips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tips, GTK_WIDGET (entry_host),
 			      _("Enter the network address to finger that user.\n"
-				"For example: www.domain.com or 192.168.2.1"),
+			        "For example: auth.domain.com or 192.168.2.1"),
 			      NULL);
 
 	completion = gtk_entry_completion_new ();
